'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-26d47dbc.js');
const api = require('./api-f3249132.js');
const uniqueId = require('./unique-id-e23fb43a.js');

const suggestions = new Map();
/** requests suggestions from url and caches responses */
const getSuggestions = (url) => {
    if (suggestions.has(url)) {
        return Promise.resolve(suggestions.get(url));
    }
    return api.api(url).then((response) => {
        suggestions.set(url, response);
        return response;
    });
};

const autosuggestInputCss = ".ux-autosuggest-input{display:block;position:relative}.ux-autosuggest-input__input-container{position:relative}.ux-autosuggest-input__suggestions{padding-top:44px;position:absolute;z-index:1;width:100%;top:0;left:0;-webkit-box-shadow:0 7px 22px rgba(19, 19, 19, 0.15);box-shadow:0 7px 22px rgba(19, 19, 19, 0.15);pointer-events:none}.ux-autosuggest-input__suggestions .ux-suggest-item{pointer-events:auto}.ux-autosuggest-input__suggestions--hidden{display:none}.ux-autosuggest-input__suggestion-link{text-decoration:none}.ux-autosuggest-input__suggestion-link:last-child .ux-suggest-item{border:0}";

class AutosuggestInput {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        /** placeholder text for input */
        this.placeholder = "";
        /** name attribute for input */
        this.name = "";
        /** id attribute for input. A unique id will be generated if this is empty */
        this.inputId = "";
        /** label for input */
        this.label = "";
        /** URL for autosuggest-API */
        this.url = "";
        this.suggestions = [];
        this.input = "";
        this.isHidden = true;
        this.id = "";
    }
    componentWillLoad() {
        const { inputId } = this;
        this.id = inputId || uniqueId.getUniqueId();
    }
    onInput(event) {
        if (this.url === "") {
            return;
        }
        const { value } = event.target;
        this.input = value;
        if (value === "") {
            this.suggestions = [];
            return;
        }
        getSuggestions(`${this.url}?q=${value}`)
            .then((response) => (this.suggestions = response))
            .catch((error) => console.error(error));
    }
    onBlur() {
        this.isHidden = true;
    }
    onFocus() {
        this.isHidden = false;
    }
    onClick(event, value) {
        event.preventDefault();
        const input = this.domNode.querySelector("input");
        input.value = value;
        this.suggestions = [];
    }
    render() {
        const baseClass = "ux-autosuggest-input";
        const { placeholder, name, suggestions, id, input, label, isHidden, } = this;
        return (index.h(index.Host, { class: baseClass, onFocusout: () => this.onBlur() }, label !== "" && (index.h("label", { class: "ux-label", htmlFor: id }, label)), index.h("div", { class: `${baseClass}__input-container` }, index.h("input", { class: "ux-input", name: name, type: "text", placeholder: placeholder, autocomplete: "off", autocapitalize: "off", id: id, onInput: (event) => this.onInput(event), onFocus: () => this.onFocus() }), index.h("div", { class: {
                [`${baseClass}__suggestions`]: true,
                [`${baseClass}__suggestions--hidden`]: isHidden,
            } }, suggestions === null || suggestions === void 0 ? void 0 : suggestions.map(({ value, description, image }) => (index.h("a", { class: `${baseClass}__suggestion-link`, href: "#", onFocus: () => this.onFocus(), onClick: (event) => this.onClick(event, value) }, index.h("ux-autosuggest-item", { text: value, input: input, subline: description, image: image }))))))));
    }
    get domNode() { return index.getElement(this); }
    static get watchers() { return {
        "inputId": ["componentWillLoad"]
    }; }
}
AutosuggestInput.style = autosuggestInputCss;

exports.ux_autosuggest_input = AutosuggestInput;
