'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-26d47dbc.js');

/** returns the matched part and the remaining part of the text */
const getSuggestionHighlight = (input, text) => {
    const firstPart = text.substring(0, input.length);
    if (firstPart.toLowerCase() !== input.toLowerCase()) {
        return ["", text];
    }
    const matchedString = firstPart;
    const remaining = text.substring(input.length);
    return [matchedString, remaining];
};

const autosuggestItemCss = ".ux-autosuggest-item{font-family:\"Frutiger-Light\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;font-weight:400;display:-ms-flexbox;display:flex;border-bottom:solid 1px #c4c4c4;color:#393939;background-color:#fff}.ux-autosuggest-item__image{width:75px;height:75px;background-size:cover;background-color:#e7e7e7}.ux-autosuggest-item__text-container{padding:15px}.ux-autosuggest-item__highlight{color:#bbd03a}.ux-autosuggest-item__subline{text-transform:uppercase}";

class AutosuggestItem {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        /** search query that will be highlighted in the text */
        this.input = "";
        /** suggestion text that matches the input */
        this.text = "";
        /** subline below the text */
        this.subline = "";
        /** optional image URL */
        this.image = "";
    }
    render() {
        const baseClass = "ux-autosuggest-item";
        const { text, subline, image, input } = this;
        const [highlight, remaining] = getSuggestionHighlight(input, text);
        return (index.h(index.Host, { class: baseClass }, image !== "" && (index.h("div", { class: `${baseClass}__image`, style: { backgroundImage: `url(${image})` } })), index.h("div", { class: `${baseClass}__text-container` }, index.h("div", { class: `${baseClass}__text` }, index.h("span", { class: `${baseClass}__highlight` }, highlight), remaining), index.h("div", { class: `${baseClass}__subline ux-text-tiny ux-text-tiny--bold` }, subline))));
    }
}
AutosuggestItem.style = autosuggestItemCss;

exports.ux_autosuggest_item = AutosuggestItem;
