'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-26d47dbc.js');

function copyToClipboard(generatedString) {
    const copyText = new Promise((resolve) => {
        if (navigator.clipboard != undefined) {
            // Modern browsers
            navigator.clipboard.writeText(generatedString).then(function () {
                resolve(true);
            }, function (err) {
                console.error("Could not copy text: ", err);
            });
        }
        else {
            // Internet Explorer
            const el = document.createElement("textarea");
            el.value = generatedString;
            document.body.appendChild(el);
            el.focus();
            el.select();
            document.execCommand("copy");
            document.body.removeChild(el);
            resolve(true);
        }
    });
    return copyText;
}

const copyToClipboardCss = ".ux-copy-to-clipboard{display:block}.ux-copy-to-clipboard__copy-area{position:relative;cursor:pointer}";

class CopyToClipboard {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        /** Default icon */
        this.clickToCopyIcon = "documents";
        /** Icon shown after copy link was clicked */
        this.clickToCopyIconSuccessful = "checkmark-rounded-thin";
        /** Setting wether link to be copied is hidden */
        this.hideTextToCopy = false;
        this.wasSuccessful = false;
        this.clickHandler = (stringToCopy) => {
            copyToClipboard(stringToCopy)
                .then((response) => {
                this.wasSuccessful = response;
            })
                .catch(function (err) {
                console.log("Could not copy link:", err);
            });
            setTimeout(() => {
                this.wasSuccessful = false;
            }, 2000);
        };
    }
    render() {
        return (index.h(index.Host, { class: "ux-copy-to-clipboard" }, this.textToCopy && (index.h("div", { onClick: () => this.clickHandler(this.textToCopy) }, !this.hideTextToCopy && (index.h("div", { class: "ux-copy-to-clipboard__text-to-copy" }, this.textToCopy)), index.h("div", { class: "ux-copy-to-clipboard__copy-area" }, index.h("span", null, this.wasSuccessful
            ? this.clickToCopyMessageSuccessful
            : this.clickToCopyMessage), index.h("ux-icon", { name: this.wasSuccessful
                ? this.clickToCopyIconSuccessful
                : this.clickToCopyIcon }))))));
    }
}
CopyToClipboard.style = copyToClipboardCss;

exports.ux_copy_to_clipboard = CopyToClipboard;
