'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-26d47dbc.js');
const uniqueId = require('./unique-id-e23fb43a.js');
const element = require('./element-e6d92b83.js');

const filterCss = ".ux-filter{display:block}";

element.applyPolyfills();
const referenceAttr = "data-reference";
class Filter {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.filterChange = index.createEvent(this, "uxFilterChange", 7);
    }
    tagRemovedHandler(event) {
        const checkbox = this.domNode.querySelector(`input[type="checkbox"][${referenceAttr}="${event.detail}"]`);
        if (checkbox !== null) {
            checkbox.checked = false;
            this.filterChange.emit();
        }
    }
    onChange(e) {
        const checkbox = e.target;
        if (!checkbox.matches('input[type="checkbox"]')) {
            return;
        }
        if (checkbox.matches(`:not(:checked)[${referenceAttr}]`)) {
            const reference = checkbox.getAttribute(referenceAttr);
            const tags = this.domNode.querySelectorAll(`ux-tag[reference="${reference}"]`);
            [].forEach.call(tags, (tag) => tag.remove());
        }
        else {
            this.addTag(checkbox);
        }
        this.filterChange.emit(e);
    }
    addTag(checkbox) {
        const reference = uniqueId.getUniqueId();
        checkbox.setAttribute(referenceAttr, reference);
        const labelText = checkbox.closest("label").innerText;
        const tagList = this.domNode.querySelector(".ux-tag-list");
        const tag = document.createElement("ux-tag");
        tag.setAttribute("reference", reference);
        tag.innerText = labelText;
        tagList.appendChild(tag);
    }
    componentDidLoad() {
        this.initFilters();
        this.initSlot();
    }
    initFilters() {
        if (typeof this.endpoint !== "string" || this.endpoint === "") {
            // TODO: uninit/reset
            return;
        }
        fetch(this.endpoint)
            .then((r) => r.json())
            .then((response) => {
            this.filterValues = response.filterValues;
            this.domNode.querySelectorAll("ux-dropdown").forEach((item) => {
                if (item.matches("[name]")) {
                    new Array(response.filterValues[item.getAttribute("name")]).forEach((filterValuesInfo) => {
                        // @ts-ignore
                        item.querySelector("ux-list").setFilterValues(filterValuesInfo);
                    });
                }
            });
        });
    }
    initSlot() {
        // check if web components in slot are correctly loaded
        // this is a workaround because of this bug: https://github.com/ionic-team/stencil/issues/1130
        if (this.domNode.querySelector(`ux-checkbox:not(.hydrated), ux-checkbox-list-item:not(.hydrated)`) !== null) {
            window.setTimeout(() => this.initSlot(), 50);
            return;
        }
        // init checkboxes that are checked at load
        const checkedCheckboxes = this.domNode.querySelectorAll(`input[type="checkbox"]:checked`);
        [].forEach.call(checkedCheckboxes, (checkbox) => this.addTag(checkbox));
    }
    render() {
        return (index.h(index.Host, { class: "ux-filter" }, index.h("form", { onSubmit: (e) => e.preventDefault(), onChange: (e) => this.onChange(e) }, index.h("slot", null))));
    }
    get domNode() { return index.getElement(this); }
    static get watchers() { return {
        "endpoint": ["initFilters"]
    }; }
}
Filter.style = filterCss;

exports.ux_filter = Filter;
