'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-26d47dbc.js');

const listCss = "ux-list{display:block}ux-list>ul{list-style-type:none;padding:0;margin:0}ux-list>ul>li{padding:0 15px}ux-list .ux-dropdown__item--hidden{display:none}";

const hiddenClass = "ux-dropdown__item--hidden";
class List {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        /** enables the search field inside the list */
        this.filterable = false;
        this.items = [];
        this.slotLabels = [];
        this.filterString = "";
        /** list element that hosts all items */
        this.ul = null;
    }
    componentDidLoad() {
        if (this.ul === null)
            return;
        [].forEach.call(this.ul.children, (child, i) => {
            const label = child.getAttribute("label");
            if (!child.matches("li")) {
                // wrap child in li element
                const li = document.createElement("li");
                child.parentNode.insertBefore(li, child);
                li.appendChild(child);
            }
            this.slotLabels[i] = label;
        });
    }
    /** returns true when item should be shown according to the filter */
    isInFilter(itemName) {
        return (this.filterString.length === 0 ||
            itemName.toLowerCase().indexOf(this.filterString) !== -1);
    }
    /** set the Content from outside */
    async setFilterValues(filterValues) {
        this.items = filterValues;
    }
    onFilterChange(event) {
        this.filterString = event.target.value.toLowerCase();
        if (this.items.length > 0)
            return;
        this.slotLabels.forEach((label, i) => {
            const element = this.ul.children[i];
            if (this.isInFilter(label)) {
                element.classList.remove(hiddenClass);
            }
            else {
                element.classList.add(hiddenClass);
            }
        });
    }
    render() {
        const filterInput = this.filterable && (index.h("div", { class: "ux-list__filter" }, index.h("input", { class: "ux-list__filter-input ux-input", type: "text", placeholder: "Search", onKeyUp: this.onFilterChange.bind(this) })));
        const hasItems = this.items.length > 0;
        return (index.h(index.Host, null, filterInput, index.h("ul", { ref: (el) => (this.ul = el), class: "ux-dropdown__list" }, index.h("slot", null), hasItems &&
            this.items.map((item) => (index.h("li", { class: {
                    [hiddenClass]: !this.isInFilter(item.label),
                } }, index.h("ux-checkbox-list-item", { label: item.label, value: item.value })))))));
    }
    get domNode() { return index.getElement(this); }
}
List.style = listCss;

exports.ux_list = List;
