import { Component, h, Prop, Host, State, Element, Watch } from "@stencil/core";
import { getSuggestions } from "./get-suggestions";
import { getUniqueId } from "../../utils/unique-id";
export class AutosuggestInput {
    constructor() {
        /** placeholder text for input */
        this.placeholder = "";
        /** name attribute for input */
        this.name = "";
        /** id attribute for input. A unique id will be generated if this is empty */
        this.inputId = "";
        /** label for input */
        this.label = "";
        /** URL for autosuggest-API */
        this.url = "";
        this.suggestions = [];
        this.input = "";
        this.isHidden = true;
        this.id = "";
    }
    componentWillLoad() {
        const { inputId } = this;
        this.id = inputId || getUniqueId();
    }
    onInput(event) {
        if (this.url === "") {
            return;
        }
        const { value } = event.target;
        this.input = value;
        if (value === "") {
            this.suggestions = [];
            return;
        }
        getSuggestions(`${this.url}?q=${value}`)
            .then((response) => (this.suggestions = response))
            .catch((error) => console.error(error));
    }
    onBlur() {
        this.isHidden = true;
    }
    onFocus() {
        this.isHidden = false;
    }
    onClick(event, value) {
        event.preventDefault();
        const input = this.domNode.querySelector("input");
        input.value = value;
        this.suggestions = [];
    }
    render() {
        const baseClass = "ux-autosuggest-input";
        const { placeholder, name, suggestions, id, input, label, isHidden, } = this;
        return (h(Host, { class: baseClass, onFocusout: () => this.onBlur() },
            label !== "" && (h("label", { class: "ux-label", htmlFor: id }, label)),
            h("div", { class: `${baseClass}__input-container` },
                h("input", { class: "ux-input", name: name, type: "text", placeholder: placeholder, autocomplete: "off", autocapitalize: "off", id: id, onInput: (event) => this.onInput(event), onFocus: () => this.onFocus() }),
                h("div", { class: {
                        [`${baseClass}__suggestions`]: true,
                        [`${baseClass}__suggestions--hidden`]: isHidden,
                    } }, suggestions === null || suggestions === void 0 ? void 0 : suggestions.map(({ value, description, image }) => (h("a", { class: `${baseClass}__suggestion-link`, href: "#", onFocus: () => this.onFocus(), onClick: (event) => this.onClick(event, value) },
                    h("ux-autosuggest-item", { text: value, input: input, subline: description, image: image }))))))));
    }
    static get is() { return "ux-autosuggest-input"; }
    static get originalStyleUrls() { return {
        "$": ["autosuggest-input.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["autosuggest-input.css"]
    }; }
    static get properties() { return {
        "placeholder": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "placeholder text for input"
            },
            "attribute": "placeholder",
            "reflect": false,
            "defaultValue": "\"\""
        },
        "name": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "name attribute for input"
            },
            "attribute": "name",
            "reflect": false,
            "defaultValue": "\"\""
        },
        "inputId": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "id attribute for input. A unique id will be generated if this is empty"
            },
            "attribute": "input-id",
            "reflect": false,
            "defaultValue": "\"\""
        },
        "label": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "label for input"
            },
            "attribute": "label",
            "reflect": false,
            "defaultValue": "\"\""
        },
        "url": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "URL for autosuggest-API"
            },
            "attribute": "url",
            "reflect": false,
            "defaultValue": "\"\""
        }
    }; }
    static get states() { return {
        "suggestions": {},
        "input": {},
        "isHidden": {},
        "id": {}
    }; }
    static get elementRef() { return "domNode"; }
    static get watchers() { return [{
            "propName": "inputId",
            "methodName": "componentWillLoad"
        }]; }
}
