import { Component, h, Prop, Host } from "@stencil/core";
import getSuggestionHighlight from "./get-suggestion-highlight";
export class AutosuggestItem {
    constructor() {
        /** search query that will be highlighted in the text */
        this.input = "";
        /** suggestion text that matches the input */
        this.text = "";
        /** subline below the text */
        this.subline = "";
        /** optional image URL */
        this.image = "";
    }
    render() {
        const baseClass = "ux-autosuggest-item";
        const { text, subline, image, input } = this;
        const [highlight, remaining] = getSuggestionHighlight(input, text);
        return (h(Host, { class: baseClass },
            image !== "" && (h("div", { class: `${baseClass}__image`, style: { backgroundImage: `url(${image})` } })),
            h("div", { class: `${baseClass}__text-container` },
                h("div", { class: `${baseClass}__text` },
                    h("span", { class: `${baseClass}__highlight` }, highlight),
                    remaining),
                h("div", { class: `${baseClass}__subline ux-text-tiny ux-text-tiny--bold` }, subline))));
    }
    static get is() { return "ux-autosuggest-item"; }
    static get originalStyleUrls() { return {
        "$": ["autosuggest-item.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["autosuggest-item.css"]
    }; }
    static get properties() { return {
        "input": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "search query that will be highlighted in the text"
            },
            "attribute": "input",
            "reflect": false,
            "defaultValue": "\"\""
        },
        "text": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "suggestion text that matches the input"
            },
            "attribute": "text",
            "reflect": false,
            "defaultValue": "\"\""
        },
        "subline": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "subline below the text"
            },
            "attribute": "subline",
            "reflect": false,
            "defaultValue": "\"\""
        },
        "image": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "optional image URL"
            },
            "attribute": "image",
            "reflect": false,
            "defaultValue": "\"\""
        }
    }; }
}
