import { Component, h, Prop, Host } from "@stencil/core";
export class Checkbox {
    constructor() {
        /** value of the input element, not visible to the user */
        this.value = "";
        /** text inside the label element, visible to the user */
        this.label = "";
        /** name which is used for checkbox groups or as identifier in forms */
        this.name = "";
        /** indicates if the checkbox is checked */
        this.checked = false;
        /** indicates if the checkbox is disabled */
        this.disabled = false;
    }
    render() {
        const baseClass = "ux-checkbox";
        return (h(Host, { class: {
                [baseClass]: true,
                [`${baseClass}--disabled`]: this.disabled,
            } },
            h("label", { class: `${baseClass}__wrapper` },
                h("input", { class: `${baseClass}__input`, type: "checkbox", value: this.value, name: this.name, checked: this.checked, disabled: this.disabled }),
                h("span", { class: `${baseClass}__icon ${baseClass}__icon--unchecked` }),
                h("span", { class: `${baseClass}__icon ${baseClass}__icon--checked` }),
                h("span", { class: `${baseClass}__label` },
                    this.label,
                    " ",
                    h("slot", null)))));
    }
    static get is() { return "ux-checkbox"; }
    static get originalStyleUrls() { return {
        "$": ["checkbox.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["checkbox.css"]
    }; }
    static get properties() { return {
        "value": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "value of the input element, not visible to the user"
            },
            "attribute": "value",
            "reflect": false,
            "defaultValue": "\"\""
        },
        "label": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "text inside the label element, visible to the user"
            },
            "attribute": "label",
            "reflect": false,
            "defaultValue": "\"\""
        },
        "name": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "name which is used for checkbox groups or as identifier in forms"
            },
            "attribute": "name",
            "reflect": false,
            "defaultValue": "\"\""
        },
        "checked": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "indicates if the checkbox is checked"
            },
            "attribute": "checked",
            "reflect": false,
            "defaultValue": "false"
        },
        "disabled": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "indicates if the checkbox is disabled"
            },
            "attribute": "disabled",
            "reflect": false,
            "defaultValue": "false"
        }
    }; }
}
