import { Component, h, Host, Prop, State } from "@stencil/core";
import copyToClipboard from "../../utils/copyToClipboard";
export class CopyToClipboard {
    constructor() {
        /** Default icon */
        this.clickToCopyIcon = "documents";
        /** Icon shown after copy link was clicked */
        this.clickToCopyIconSuccessful = "checkmark-rounded-thin";
        /** Setting wether link to be copied is hidden */
        this.hideTextToCopy = false;
        this.wasSuccessful = false;
        this.clickHandler = (stringToCopy) => {
            copyToClipboard(stringToCopy)
                .then((response) => {
                this.wasSuccessful = response;
            })
                .catch(function (err) {
                console.log("Could not copy link:", err);
            });
            setTimeout(() => {
                this.wasSuccessful = false;
            }, 2000);
        };
    }
    render() {
        return (h(Host, { class: "ux-copy-to-clipboard" }, this.textToCopy && (h("div", { onClick: () => this.clickHandler(this.textToCopy) },
            !this.hideTextToCopy && (h("div", { class: "ux-copy-to-clipboard__text-to-copy" }, this.textToCopy)),
            h("div", { class: "ux-copy-to-clipboard__copy-area" },
                h("span", null, this.wasSuccessful
                    ? this.clickToCopyMessageSuccessful
                    : this.clickToCopyMessage),
                h("ux-icon", { name: this.wasSuccessful
                        ? this.clickToCopyIconSuccessful
                        : this.clickToCopyIcon }))))));
    }
    static get is() { return "ux-copy-to-clipboard"; }
    static get originalStyleUrls() { return {
        "$": ["copy-to-clipboard.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["copy-to-clipboard.css"]
    }; }
    static get properties() { return {
        "textToCopy": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Link which can be copied"
            },
            "attribute": "text-to-copy",
            "reflect": true
        },
        "clickToCopyIcon": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Default icon"
            },
            "attribute": "click-to-copy-icon",
            "reflect": false,
            "defaultValue": "\"documents\""
        },
        "clickToCopyIconSuccessful": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Icon shown after copy link was clicked"
            },
            "attribute": "click-to-copy-icon-successful",
            "reflect": false,
            "defaultValue": "\"checkmark-rounded-thin\""
        },
        "clickToCopyMessage": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Default message which indicates link is copyable"
            },
            "attribute": "click-to-copy-message",
            "reflect": false
        },
        "clickToCopyMessageSuccessful": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Message which gets shown after clicking the copy link"
            },
            "attribute": "click-to-copy-message-successful",
            "reflect": false
        },
        "hideTextToCopy": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "Setting wether link to be copied is hidden"
            },
            "attribute": "hide-text-to-copy",
            "reflect": false,
            "defaultValue": "false"
        }
    }; }
    static get states() { return {
        "wasSuccessful": {}
    }; }
}
