import { Component, Host, Element, Event, Listen, Prop, Watch, State, h, } from "@stencil/core";
import { getUniqueId } from "../../utils/unique-id";
import applyElementPolyfills from "../../polyfills/element";
applyElementPolyfills();
const referenceAttr = "data-reference";
export class Filter {
    tagRemovedHandler(event) {
        const checkbox = this.domNode.querySelector(`input[type="checkbox"][${referenceAttr}="${event.detail}"]`);
        if (checkbox !== null) {
            checkbox.checked = false;
            this.filterChange.emit();
        }
    }
    onChange(e) {
        const checkbox = e.target;
        if (!checkbox.matches('input[type="checkbox"]')) {
            return;
        }
        if (checkbox.matches(`:not(:checked)[${referenceAttr}]`)) {
            const reference = checkbox.getAttribute(referenceAttr);
            const tags = this.domNode.querySelectorAll(`ux-tag[reference="${reference}"]`);
            [].forEach.call(tags, (tag) => tag.remove());
        }
        else {
            this.addTag(checkbox);
        }
        this.filterChange.emit(e);
    }
    addTag(checkbox) {
        const reference = getUniqueId();
        checkbox.setAttribute(referenceAttr, reference);
        const labelText = checkbox.closest("label").innerText;
        const tagList = this.domNode.querySelector(".ux-tag-list");
        const tag = document.createElement("ux-tag");
        tag.setAttribute("reference", reference);
        tag.innerText = labelText;
        tagList.appendChild(tag);
    }
    componentDidLoad() {
        this.initFilters();
        this.initSlot();
    }
    initFilters() {
        if (typeof this.endpoint !== "string" || this.endpoint === "") {
            // TODO: uninit/reset
            return;
        }
        fetch(this.endpoint)
            .then((r) => r.json())
            .then((response) => {
            this.filterValues = response.filterValues;
            this.domNode.querySelectorAll("ux-dropdown").forEach((item) => {
                if (item.matches("[name]")) {
                    new Array(response.filterValues[item.getAttribute("name")]).forEach((filterValuesInfo) => {
                        // @ts-ignore
                        item.querySelector("ux-list").setFilterValues(filterValuesInfo);
                    });
                }
            });
        });
    }
    initSlot() {
        // check if web components in slot are correctly loaded
        // this is a workaround because of this bug: https://github.com/ionic-team/stencil/issues/1130
        if (this.domNode.querySelector(`ux-checkbox:not(.hydrated), ux-checkbox-list-item:not(.hydrated)`) !== null) {
            window.setTimeout(() => this.initSlot(), 50);
            return;
        }
        // init checkboxes that are checked at load
        const checkedCheckboxes = this.domNode.querySelectorAll(`input[type="checkbox"]:checked`);
        [].forEach.call(checkedCheckboxes, (checkbox) => this.addTag(checkbox));
    }
    render() {
        return (h(Host, { class: "ux-filter" },
            h("form", { onSubmit: (e) => e.preventDefault(), onChange: (e) => this.onChange(e) },
                h("slot", null))));
    }
    static get is() { return "ux-filter"; }
    static get originalStyleUrls() { return {
        "$": ["filter.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["filter.css"]
    }; }
    static get properties() { return {
        "endpoint": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "This is a URL to a JSON API."
            },
            "attribute": "endpoint",
            "reflect": true
        }
    }; }
    static get states() { return {
        "filterValues": {}
    }; }
    static get events() { return [{
            "method": "filterChange",
            "name": "uxFilterChange",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "is triggered when any input inside the filter was changed"
            },
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            }
        }]; }
    static get elementRef() { return "domNode"; }
    static get watchers() { return [{
            "propName": "endpoint",
            "methodName": "initFilters"
        }]; }
    static get listeners() { return [{
            "name": "uxRemove",
            "method": "tagRemovedHandler",
            "target": undefined,
            "capture": false,
            "passive": false
        }]; }
}
