import { Component, h, Prop, State, Host, Watch, getAssetPath, } from "@stencil/core";
import { getSvgContent, iconContent } from "./request";
import availableIcons from "./availableIcons";
/**
 * this component is heavily inspired by https://github.com/ionic-team/ionicons
 */
export class Icon {
    constructor() {
        /** name of icon */
        this.name = "";
        /** contains the full svg */
        this.svgContent = null;
    }
    connectedCallback() {
        this.loadIcon();
    }
    loadIcon() {
        if (this.name === "") {
            return;
        }
        if (availableIcons.indexOf(this.name) === -1) {
            if (loggedWarnings.indexOf(this.name) !== -1)
                return;
            console.warn(`Icon ${this.name} is not available in ux-icon.`);
            loggedWarnings.push(this.name);
            return;
        }
        const url = getAssetPath(`./assets/${this.name}.svg`);
        if (iconContent.has(url)) {
            // sync if it's already loaded
            this.svgContent = iconContent.get(url);
        }
        else {
            // async if it hasn't been loaded
            getSvgContent(url).then(() => (this.svgContent = iconContent.get(url)));
        }
    }
    render() {
        if (this.name === "" || this.svgContent === null) {
            return null;
        }
        return (h(Host, { class: "ux-icon" },
            h("div", { class: "ux-icon__inner", innerHTML: this.svgContent })));
    }
    static get is() { return "ux-icon"; }
    static get originalStyleUrls() { return {
        "$": ["icon.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["icon.css"]
    }; }
    static get assetsDirs() { return ["assets"]; }
    static get properties() { return {
        "name": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "name of icon"
            },
            "attribute": "name",
            "reflect": true,
            "defaultValue": "\"\""
        }
    }; }
    static get states() { return {
        "svgContent": {}
    }; }
    static get watchers() { return [{
            "propName": "name",
            "methodName": "loadIcon"
        }]; }
}
// this array holds logged warnings about unknown icons to prevent duplicate warnings
const loggedWarnings = [];
