import { Component, Host, Element, Prop, Method, h, State, } from "@stencil/core";
const hiddenClass = "ux-dropdown__item--hidden";
export class List {
    constructor() {
        /** enables the search field inside the list */
        this.filterable = false;
        this.items = [];
        this.slotLabels = [];
        this.filterString = "";
        /** list element that hosts all items */
        this.ul = null;
    }
    componentDidLoad() {
        if (this.ul === null)
            return;
        [].forEach.call(this.ul.children, (child, i) => {
            const label = child.getAttribute("label");
            if (!child.matches("li")) {
                // wrap child in li element
                const li = document.createElement("li");
                child.parentNode.insertBefore(li, child);
                li.appendChild(child);
            }
            this.slotLabels[i] = label;
        });
    }
    /** returns true when item should be shown according to the filter */
    isInFilter(itemName) {
        return (this.filterString.length === 0 ||
            itemName.toLowerCase().indexOf(this.filterString) !== -1);
    }
    /** set the Content from outside */
    async setFilterValues(filterValues) {
        this.items = filterValues;
    }
    onFilterChange(event) {
        this.filterString = event.target.value.toLowerCase();
        if (this.items.length > 0)
            return;
        this.slotLabels.forEach((label, i) => {
            const element = this.ul.children[i];
            if (this.isInFilter(label)) {
                element.classList.remove(hiddenClass);
            }
            else {
                element.classList.add(hiddenClass);
            }
        });
    }
    render() {
        const filterInput = this.filterable && (h("div", { class: "ux-list__filter" },
            h("input", { class: "ux-list__filter-input ux-input", type: "text", placeholder: "Search", onKeyUp: this.onFilterChange.bind(this) })));
        const hasItems = this.items.length > 0;
        return (h(Host, null,
            filterInput,
            h("ul", { ref: (el) => (this.ul = el), class: "ux-dropdown__list" },
                h("slot", null),
                hasItems &&
                    this.items.map((item) => (h("li", { class: {
                            [hiddenClass]: !this.isInFilter(item.label),
                        } },
                        h("ux-checkbox-list-item", { label: item.label, value: item.value })))))));
    }
    static get is() { return "ux-list"; }
    static get originalStyleUrls() { return {
        "$": ["list.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["list.css"]
    }; }
    static get properties() { return {
        "filterable": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "enables the search field inside the list"
            },
            "attribute": "filterable",
            "reflect": true,
            "defaultValue": "false"
        }
    }; }
    static get states() { return {
        "items": {},
        "slotLabels": {},
        "filterString": {}
    }; }
    static get methods() { return {
        "setFilterValues": {
            "complexType": {
                "signature": "(filterValues: Array<any>) => Promise<void>",
                "parameters": [{
                        "tags": [],
                        "text": ""
                    }],
                "references": {
                    "Promise": {
                        "location": "global"
                    },
                    "Array": {
                        "location": "global"
                    }
                },
                "return": "Promise<void>"
            },
            "docs": {
                "text": "set the Content from outside",
                "tags": []
            }
        }
    }; }
    static get elementRef() { return "domNode"; }
}
