import { Component, Prop, h, Host, Element, State, Watch } from "@stencil/core";
import { calculateValue, getValidatedValue, getNumberValue, } from "./number-input-utils";
export class NumberInput {
    constructor() {
        /** name attribute for the input */
        this.name = "";
        /** initial value for the input */
        this.initialValue = "0";
        /** size of increment/decrement for the plus/minus button */
        this.step = "1";
        /** max value */
        this.max = "";
        /** min value */
        this.min = "";
    }
    componentWillLoad() {
        const { initialValue } = this;
        const initialNumber = +initialValue;
        if (!isNaN(initialNumber)) {
            this.value = initialNumber;
        }
        this.setNumbers();
    }
    setNumbers() {
        const { max, min, step } = this;
        this.minValue = getNumberValue(min);
        this.maxValue = getNumberValue(max);
        const stepValue = getNumberValue(step);
        this.stepValue = isNaN(stepValue) ? 1 : stepValue;
    }
    handlePlus() {
        this.changeValue("increment");
    }
    handleMinus() {
        this.changeValue("decrement");
    }
    changeValue(type = "increment") {
        const { stepValue, maxValue, minValue, value } = this;
        this.value = calculateValue(type, value, stepValue, maxValue, minValue);
    }
    onChange(event) {
        const { maxValue, minValue } = this;
        const { value } = event.target;
        this.value = getValidatedValue(value, this.value, maxValue, minValue);
        event.target.value = this.value;
    }
    render() {
        const baseClass = "ux-number-input";
        const { name, max, min, stepValue, value } = this;
        return (h(Host, { class: baseClass },
            h("button", { type: "button", class: `${baseClass}__btn`, onClick: () => this.handleMinus() }, "\u2013"),
            h("input", { class: `${baseClass}__input`, name: name, step: stepValue.toString(), type: "number", max: max, min: min, value: value, onInput: (event) => this.onChange(event) }),
            h("button", { type: "button", class: `${baseClass}__btn`, onClick: () => this.handlePlus() }, "+")));
    }
    static get is() { return "ux-number-input"; }
    static get originalStyleUrls() { return {
        "$": ["number-input.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["number-input.css"]
    }; }
    static get properties() { return {
        "name": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "name attribute for the input"
            },
            "attribute": "name",
            "reflect": false,
            "defaultValue": "\"\""
        },
        "initialValue": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "initial value for the input"
            },
            "attribute": "initial-value",
            "reflect": false,
            "defaultValue": "\"0\""
        },
        "step": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "size of increment/decrement for the plus/minus button"
            },
            "attribute": "step",
            "reflect": false,
            "defaultValue": "\"1\""
        },
        "max": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "max value"
            },
            "attribute": "max",
            "reflect": false,
            "defaultValue": "\"\""
        },
        "min": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "min value"
            },
            "attribute": "min",
            "reflect": false,
            "defaultValue": "\"\""
        }
    }; }
    static get states() { return {
        "value": {},
        "minValue": {},
        "maxValue": {},
        "stepValue": {}
    }; }
    static get elementRef() { return "domNode"; }
    static get watchers() { return [{
            "propName": "min",
            "methodName": "setNumbers"
        }, {
            "propName": "max",
            "methodName": "setNumbers"
        }, {
            "propName": "step",
            "methodName": "setNumbers"
        }]; }
}
