import { Component, Host, h, Element, Event, Prop, } from "@stencil/core";
import applyPolyfills from "../../../polyfills/element";
applyPolyfills();
export class TableSort {
    constructor() {
        /** indicates in which direction the data is already sorted. This has to be empty when it is not sorted yet. Setting this does not trigger the sorting event. Clicking the button will update this attribute. */
        this.sortedDirection = "";
    }
    sort() {
        this.sortedDirection = this.sortedDirection !== "asc" ? "asc" : "desc";
        const name = this.sortedDirection === "asc" ? this.ascName : this.descName;
        this.sortEvent.emit(name);
        const allSorters = this.domElement
            .closest("tr")
            .querySelectorAll("ux-table-sort");
        [].forEach.call(allSorters, (element) => {
            if (element.isEqualNode(this.domElement))
                return;
            element.sortedDirection = "";
        });
    }
    render() {
        const baseClass = "ux-table-sort";
        return (h(Host, { class: baseClass, onClick: () => this.sort() },
            h("slot", null),
            "\u00A0",
            h("ux-icon", { class: `${baseClass}__icon`, name: "sort" })));
    }
    static get is() { return "ux-table-sort"; }
    static get originalStyleUrls() { return {
        "$": ["table-sort.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["table-sort.css"]
    }; }
    static get properties() { return {
        "ascName": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "This is the name to send when it should sort ascending"
            },
            "attribute": "asc-name",
            "reflect": false
        },
        "descName": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "This is the name to send when it should sort descending"
            },
            "attribute": "desc-name",
            "reflect": false
        },
        "sortedDirection": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "\"\" | \"asc\" | \"desc\"",
                "resolved": "\"\" | \"asc\" | \"desc\"",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "indicates in which direction the data is already sorted. This has to be empty when it is not sorted yet. Setting this does not trigger the sorting event. Clicking the button will update this attribute."
            },
            "attribute": "sorted-direction",
            "reflect": true,
            "defaultValue": "\"\""
        }
    }; }
    static get events() { return [{
            "method": "sortEvent",
            "name": "uxTableSort",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "when the sort Button is clicked it emits the asc or desc name"
            },
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            }
        }]; }
    static get elementRef() { return "domElement"; }
}
