import { Component, Prop, Host, h, Element, Event, Method, } from "@stencil/core";
export class TabContainer {
    constructor() {
        /** prop which holds the active tab id */
        this.activeTabId = "";
        /** when this is true, the tab navigation will not be displayed */
        this.noNavigation = false;
    }
    /** id of the tab which will be active */
    async setActiveTab(id) {
        this.activeTabId = id;
        this.activeTabEvent.emit(id);
    }
    componentWillLoad() {
        var _a;
        const children = Array.from(this.domNode.children);
        this.children = children;
        if (this.activeTabId !== "") {
            this.setActiveTab(this.activeTabId);
        }
        else {
            this.setActiveTab((_a = this.children[0]) === null || _a === void 0 ? void 0 : _a.tabId);
        }
    }
    render() {
        return (h(Host, { class: "ux-tab-container" },
            !this.noNavigation && (h("div", { class: "ux-tab-container__tab-header" }, this.children.map((tab) => (h("ux-tab-button", { onClick: () => this.setActiveTab(tab.tabId), name: tab.name, tabId: tab.tabId, activeTab: this.activeTabId }))))),
            h("div", { class: "ux-tab-container__tab-body" },
                h("slot", null))));
    }
    static get is() { return "ux-tab-container"; }
    static get originalStyleUrls() { return {
        "$": ["tab-container.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["tab-container.css"]
    }; }
    static get properties() { return {
        "activeTabId": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "prop which holds the active tab id"
            },
            "attribute": "active-tab-id",
            "reflect": true,
            "defaultValue": "\"\""
        },
        "noNavigation": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "when this is true, the tab navigation will not be displayed"
            },
            "attribute": "no-navigation",
            "reflect": false,
            "defaultValue": "false"
        }
    }; }
    static get events() { return [{
            "method": "activeTabEvent",
            "name": "uxActiveTabSet",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "event when the active tab was set"
            },
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            }
        }]; }
    static get methods() { return {
        "setActiveTab": {
            "complexType": {
                "signature": "(id: string) => Promise<void>",
                "parameters": [{
                        "tags": [],
                        "text": ""
                    }],
                "references": {
                    "Promise": {
                        "location": "global"
                    }
                },
                "return": "Promise<void>"
            },
            "docs": {
                "text": "id of the tab which will be active",
                "tags": []
            }
        }
    }; }
    static get elementRef() { return "domNode"; }
}
