import { Component, Prop, Host, h, State } from "@stencil/core";
import applyElementPolyfills from "../../../polyfills/element";
applyElementPolyfills();
export class TabSwitcher {
    constructor() {
        /** identifier of the targeted tab */
        this.tabId = "";
        this.tabContainer = null;
        /** shows the button as activated - this should be in sync with the tab */
        this.active = false;
    }
    componentWillLoad() {
        if (this.tabId === "")
            return;
        this.tabContainer = document
            .querySelector(`ux-tab[tab-id=${this.tabId}]`)
            .closest("ux-tab-container");
        this.active = this.tabContainer.activeTabId === this.tabId;
        this.tabContainer.addEventListener("uxActiveTabSet", (e) => {
            this.active = e.detail === this.tabId;
        });
    }
    render() {
        return (h(Host, { class: `ux-tab-switcher ux-button ux-button--${this.active ? "toggle-active" : "toggle"}`, onClick: () => {
                if (this.tabContainer === null || this.tabId === "")
                    return;
                this.tabContainer.setActiveTab(this.tabId);
            } },
            h("slot", null)));
    }
    static get is() { return "ux-tab-switcher"; }
    static get originalStyleUrls() { return {
        "$": ["tab-switcher.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["tab-switcher.css"]
    }; }
    static get properties() { return {
        "tabId": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "identifier of the targeted tab"
            },
            "attribute": "tab-id",
            "reflect": false,
            "defaultValue": "\"\""
        }
    }; }
    static get states() { return {
        "active": {}
    }; }
}
