import { r as registerInstance, h, H as Host, g as getElement } from './index-6beb7a83.js';
import { a as api } from './api-0a9a464a.js';
import { g as getUniqueId } from './unique-id-58f78b07.js';
var suggestions = new Map();
/** requests suggestions from url and caches responses */
var getSuggestions = function (url) {
    if (suggestions.has(url)) {
        return Promise.resolve(suggestions.get(url));
    }
    return api(url).then(function (response) {
        suggestions.set(url, response);
        return response;
    });
};
var autosuggestInputCss = ".ux-autosuggest-input{display:block;position:relative}.ux-autosuggest-input__input-container{position:relative}.ux-autosuggest-input__suggestions{padding-top:44px;position:absolute;z-index:1;width:100%;top:0;left:0;-webkit-box-shadow:0 7px 22px rgba(19, 19, 19, 0.15);box-shadow:0 7px 22px rgba(19, 19, 19, 0.15);pointer-events:none}.ux-autosuggest-input__suggestions .ux-suggest-item{pointer-events:auto}.ux-autosuggest-input__suggestions--hidden{display:none}.ux-autosuggest-input__suggestion-link{text-decoration:none}.ux-autosuggest-input__suggestion-link:last-child .ux-suggest-item{border:0}";
var AutosuggestInput = /** @class */ (function () {
    function AutosuggestInput(hostRef) {
        registerInstance(this, hostRef);
        /** placeholder text for input */
        this.placeholder = "";
        /** name attribute for input */
        this.name = "";
        /** id attribute for input. A unique id will be generated if this is empty */
        this.inputId = "";
        /** label for input */
        this.label = "";
        /** URL for autosuggest-API */
        this.url = "";
        this.suggestions = [];
        this.input = "";
        this.isHidden = true;
        this.id = "";
    }
    AutosuggestInput.prototype.componentWillLoad = function () {
        var inputId = this.inputId;
        this.id = inputId || getUniqueId();
    };
    AutosuggestInput.prototype.onInput = function (event) {
        var _this = this;
        if (this.url === "") {
            return;
        }
        var value = event.target.value;
        this.input = value;
        if (value === "") {
            this.suggestions = [];
            return;
        }
        getSuggestions(this.url + "?q=" + value)
            .then(function (response) { return (_this.suggestions = response); })
            .catch(function (error) { return console.error(error); });
    };
    AutosuggestInput.prototype.onBlur = function () {
        this.isHidden = true;
    };
    AutosuggestInput.prototype.onFocus = function () {
        this.isHidden = false;
    };
    AutosuggestInput.prototype.onClick = function (event, value) {
        event.preventDefault();
        var input = this.domNode.querySelector("input");
        input.value = value;
        this.suggestions = [];
    };
    AutosuggestInput.prototype.render = function () {
        var _a;
        var _this = this;
        var baseClass = "ux-autosuggest-input";
        var _b = this, placeholder = _b.placeholder, name = _b.name, suggestions = _b.suggestions, id = _b.id, input = _b.input, label = _b.label, isHidden = _b.isHidden;
        return (h(Host, { class: baseClass, onFocusout: function () { return _this.onBlur(); } }, label !== "" && (h("label", { class: "ux-label", htmlFor: id }, label)), h("div", { class: baseClass + "__input-container" }, h("input", { class: "ux-input", name: name, type: "text", placeholder: placeholder, autocomplete: "off", autocapitalize: "off", id: id, onInput: function (event) { return _this.onInput(event); }, onFocus: function () { return _this.onFocus(); } }), h("div", { class: (_a = {},
                _a[baseClass + "__suggestions"] = true,
                _a[baseClass + "__suggestions--hidden"] = isHidden,
                _a) }, suggestions === null || suggestions === void 0 ? void 0 : suggestions.map(function (_a) {
            var value = _a.value, description = _a.description, image = _a.image;
            return (h("a", { class: baseClass + "__suggestion-link", href: "#", onFocus: function () { return _this.onFocus(); }, onClick: function (event) { return _this.onClick(event, value); } }, h("ux-autosuggest-item", { text: value, input: input, subline: description, image: image })));
        })))));
    };
    Object.defineProperty(AutosuggestInput.prototype, "domNode", {
        get: function () { return getElement(this); },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AutosuggestInput, "watchers", {
        get: function () {
            return {
                "inputId": ["componentWillLoad"]
            };
        },
        enumerable: false,
        configurable: true
    });
    return AutosuggestInput;
}());
AutosuggestInput.style = autosuggestInputCss;
export { AutosuggestInput as ux_autosuggest_input };
