import { r as registerInstance, c as createEvent, h, H as Host, g as getElement } from './index-6beb7a83.js';
import { a as api } from './api-0a9a464a.js';
function getAttributes(element) {
    if (typeof element === "undefined")
        return {};
    var nodeMap = element.attributes;
    var length = nodeMap.length;
    return Object.keys(nodeMap).reduce(function (props, current) {
        var _a;
        try {
            var numCurrent = parseInt(current);
            if (numCurrent < length) {
                var property = nodeMap[current];
                return Object.assign(Object.assign({}, props), (_a = {}, _a[property.name] = property.value, _a));
            }
        }
        catch (err) {
            // nothing
        }
    }, {});
}
var filterObject = function (originalObject, ignoreList) { return Object.keys(originalObject)
    .filter(function (key) { return !ignoreList.includes(key); })
    .reduce(function (obj, key) {
    var _a;
    return (Object.assign(Object.assign({}, obj), (_a = {}, _a[key] = originalObject[key], _a)));
}, {}); };
var dataIngestCss = ".ux-data-ingest{display:block}";
/** these common HTML attributes will not be considered for fetching data */
var ignoreAttributeList = [
    "class",
    "id",
    "style",
    "slot",
    "tabindex",
    "title",
];
var DataIngest = /** @class */ (function () {
    function DataIngest(hostRef) {
        registerInstance(this, hostRef);
        /** contains the filtered attributes with their URLs */
        this.attributes = {};
        this.startRequest = createEvent(this, "uxStartRequest", 7);
    }
    DataIngest.prototype.componentWillLoad = function () {
        var _this = this;
        this.refreshAttributes();
        this.observer = new MutationObserver(function () { return _this.refreshAttributes(); });
        this.observer.observe(this.host, {
            attributes: true,
            childList: false,
            subtree: false,
        });
    };
    DataIngest.prototype.disconnectedCallback = function () {
        this.observer.disconnect();
    };
    /** reads the attributes and their URLs and matches them with the previous ones */
    DataIngest.prototype.refreshAttributes = function () {
        var _this = this;
        var oldAttributes = this.attributes;
        this.attributes = filterObject(getAttributes(this.host), ignoreAttributeList);
        Object.keys(this.attributes).forEach(function (key) {
            if (_this.attributes[key] !== oldAttributes[key]) {
                _this.loadData(key);
            }
        });
    };
    /** loads the data from the url supplied via attribute to put it onto the child element */
    DataIngest.prototype.loadData = function (attributeName) {
        var url = this.attributes[attributeName];
        if (url === "")
            return;
        this.startRequest.emit(attributeName);
        var child = this.host.firstElementChild;
        var loading = attributeName + "Loading";
        if (child === null) {
            return;
        }
        child[loading] = true;
        api(url)
            .then(function (result) {
            child[loading] = false;
            child[attributeName] = result;
        })
            .catch(function () {
            child[loading] = false;
        });
    };
    DataIngest.prototype.render = function () {
        return (h(Host, { class: "ux-data-ingest" }, h("slot", null)));
    };
    Object.defineProperty(DataIngest.prototype, "host", {
        get: function () { return getElement(this); },
        enumerable: false,
        configurable: true
    });
    return DataIngest;
}());
DataIngest.style = dataIngestCss;
export { DataIngest as ux_data_ingest };
