import { r as registerInstance, c as createEvent, h, H as Host, g as getElement } from './index-6beb7a83.js';
import { g as getUniqueId } from './unique-id-58f78b07.js';
import { a as applyPolyfills } from './element-f64f78c4.js';
var filterCss = ".ux-filter{display:block}";
applyPolyfills();
var referenceAttr = "data-reference";
var Filter = /** @class */ (function () {
    function Filter(hostRef) {
        registerInstance(this, hostRef);
        this.filterChange = createEvent(this, "uxFilterChange", 7);
    }
    Filter.prototype.tagRemovedHandler = function (event) {
        var checkbox = this.domNode.querySelector("input[type=\"checkbox\"][" + referenceAttr + "=\"" + event.detail + "\"]");
        if (checkbox !== null) {
            checkbox.checked = false;
            this.filterChange.emit();
        }
    };
    Filter.prototype.onChange = function (e) {
        var checkbox = e.target;
        if (!checkbox.matches('input[type="checkbox"]')) {
            return;
        }
        if (checkbox.matches(":not(:checked)[" + referenceAttr + "]")) {
            var reference = checkbox.getAttribute(referenceAttr);
            var tags = this.domNode.querySelectorAll("ux-tag[reference=\"" + reference + "\"]");
            [].forEach.call(tags, function (tag) { return tag.remove(); });
        }
        else {
            this.addTag(checkbox);
        }
        this.filterChange.emit(e);
    };
    Filter.prototype.addTag = function (checkbox) {
        var reference = getUniqueId();
        checkbox.setAttribute(referenceAttr, reference);
        var labelText = checkbox.closest("label").innerText;
        var tagList = this.domNode.querySelector(".ux-tag-list");
        var tag = document.createElement("ux-tag");
        tag.setAttribute("reference", reference);
        tag.innerText = labelText;
        tagList.appendChild(tag);
    };
    Filter.prototype.componentDidLoad = function () {
        this.initFilters();
        this.initSlot();
    };
    Filter.prototype.initFilters = function () {
        var _this = this;
        if (typeof this.endpoint !== "string" || this.endpoint === "") {
            // TODO: uninit/reset
            return;
        }
        fetch(this.endpoint)
            .then(function (r) { return r.json(); })
            .then(function (response) {
            _this.filterValues = response.filterValues;
            _this.domNode.querySelectorAll("ux-dropdown").forEach(function (item) {
                if (item.matches("[name]")) {
                    new Array(response.filterValues[item.getAttribute("name")]).forEach(function (filterValuesInfo) {
                        // @ts-ignore
                        item.querySelector("ux-list").setFilterValues(filterValuesInfo);
                    });
                }
            });
        });
    };
    Filter.prototype.initSlot = function () {
        var _this = this;
        // check if web components in slot are correctly loaded
        // this is a workaround because of this bug: https://github.com/ionic-team/stencil/issues/1130
        if (this.domNode.querySelector("ux-checkbox:not(.hydrated), ux-checkbox-list-item:not(.hydrated)") !== null) {
            window.setTimeout(function () { return _this.initSlot(); }, 50);
            return;
        }
        // init checkboxes that are checked at load
        var checkedCheckboxes = this.domNode.querySelectorAll("input[type=\"checkbox\"]:checked");
        [].forEach.call(checkedCheckboxes, function (checkbox) { return _this.addTag(checkbox); });
    };
    Filter.prototype.render = function () {
        var _this = this;
        return (h(Host, { class: "ux-filter" }, h("form", { onSubmit: function (e) { return e.preventDefault(); }, onChange: function (e) { return _this.onChange(e); } }, h("slot", null))));
    };
    Object.defineProperty(Filter.prototype, "domNode", {
        get: function () { return getElement(this); },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Filter, "watchers", {
        get: function () {
            return {
                "endpoint": ["initFilters"]
            };
        },
        enumerable: false,
        configurable: true
    });
    return Filter;
}());
Filter.style = filterCss;
export { Filter as ux_filter };
