import { r as registerInstance, h, H as Host, g as getElement } from './index-6beb7a83.js';
var getValidatedValue = function (newValue, oldValue, max, min) {
    var newNumber = +newValue;
    if (isNaN(newNumber)) {
        return oldValue;
    }
    if (!isNaN(max) && newNumber > max) {
        return max;
    }
    if (!isNaN(min) && newNumber < min) {
        return min;
    }
    return Math.round(newNumber);
};
var calculateValue = function (type, value, increment, max, min) {
    var factor = type === "decrement" ? -1 : 1;
    var newValue = value + factor * increment;
    return getValidatedValue(newValue, value, max, min);
};
var getNumberValue = function (string) {
    var number = string === "" ? NaN : +string;
    return number;
};
var numberInputCss = ".ux-number-input{display:-ms-flexbox;display:flex;border:1px solid black}.ux-number-input__input[type=number]{text-align:center;padding:12px 10px;-ms-flex:1 1 0px;flex:1 1 0;width:auto;min-width:45px;border-radius:0;border:1px solid black;border-top-width:0;border-bottom-width:0;appearance:none;-webkit-appearance:none;-moz-appearance:textfield}.ux-number-input__input[type=number]::-webkit-outer-spin-button,.ux-number-input__input[type=number]::-webkit-inner-spin-button{-webkit-appearance:none;appearance:none}.ux-number-input__btn{-webkit-appearance:none;-moz-appearance:none;appearance:none;border:0;background:#e7e7e7;min-width:45px;-ms-flex:0 1 45px;flex:0 1 45px;text-align:center;border-radius:0}";
var NumberInput = /** @class */ (function () {
    function NumberInput(hostRef) {
        registerInstance(this, hostRef);
        /** name attribute for the input */
        this.name = "";
        /** initial value for the input */
        this.initialValue = "0";
        /** size of increment/decrement for the plus/minus button */
        this.step = "1";
        /** max value */
        this.max = "";
        /** min value */
        this.min = "";
    }
    NumberInput.prototype.componentWillLoad = function () {
        var initialValue = this.initialValue;
        var initialNumber = +initialValue;
        if (!isNaN(initialNumber)) {
            this.value = initialNumber;
        }
        this.setNumbers();
    };
    NumberInput.prototype.setNumbers = function () {
        var _a = this, max = _a.max, min = _a.min, step = _a.step;
        this.minValue = getNumberValue(min);
        this.maxValue = getNumberValue(max);
        var stepValue = getNumberValue(step);
        this.stepValue = isNaN(stepValue) ? 1 : stepValue;
    };
    NumberInput.prototype.handlePlus = function () {
        this.changeValue("increment");
    };
    NumberInput.prototype.handleMinus = function () {
        this.changeValue("decrement");
    };
    NumberInput.prototype.changeValue = function (type) {
        if (type === void 0) { type = "increment"; }
        var _a = this, stepValue = _a.stepValue, maxValue = _a.maxValue, minValue = _a.minValue, value = _a.value;
        this.value = calculateValue(type, value, stepValue, maxValue, minValue);
    };
    NumberInput.prototype.onChange = function (event) {
        var _a = this, maxValue = _a.maxValue, minValue = _a.minValue;
        var value = event.target.value;
        this.value = getValidatedValue(value, this.value, maxValue, minValue);
        event.target.value = this.value;
    };
    NumberInput.prototype.render = function () {
        var _this = this;
        var baseClass = "ux-number-input";
        var _a = this, name = _a.name, max = _a.max, min = _a.min, stepValue = _a.stepValue, value = _a.value;
        return (h(Host, { class: baseClass }, h("button", { type: "button", class: baseClass + "__btn", onClick: function () { return _this.handleMinus(); } }, "\u2013"), h("input", { class: baseClass + "__input", name: name, step: stepValue.toString(), type: "number", max: max, min: min, value: value, onInput: function (event) { return _this.onChange(event); } }), h("button", { type: "button", class: baseClass + "__btn", onClick: function () { return _this.handlePlus(); } }, "+")));
    };
    Object.defineProperty(NumberInput.prototype, "domNode", {
        get: function () { return getElement(this); },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NumberInput, "watchers", {
        get: function () {
            return {
                "min": ["setNumbers"],
                "max": ["setNumbers"],
                "step": ["setNumbers"]
            };
        },
        enumerable: false,
        configurable: true
    });
    return NumberInput;
}());
NumberInput.style = numberInputCss;
export { NumberInput as ux_number_input };
