import { r as registerInstance, h, H as Host, g as getElement } from './index-6beb7a83.js';
import { a as applyPolyfills } from './element-f64f78c4.js';
import { t as throttle } from './throttle-2fb7d237.js';
/** Avoid running the same function twice within the specified timeframe. */
var debounce = function (func, wait, immediate) {
    if (immediate === void 0) { immediate = false; }
    var timeout;
    return function () {
        var context = this, args = arguments;
        clearTimeout(timeout);
        timeout = setTimeout(function () {
            timeout = null;
            if (!immediate)
                func.apply(context, args);
        }, wait);
        if (immediate && !timeout)
            func.apply(context, args);
    };
};
var tableCss = ".ux-table{display:block;position:relative}.ux-table table{border-collapse:collapse;border-spacing:0;margin:0 auto;width:-webkit-max-content;width:-moz-max-content;width:max-content}.ux-table td,.ux-table th{padding:30px;text-align:left;white-space:normal}.ux-table td{font-family:\"Frutiger-Light\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;font-weight:400;font-size:16px;text-transform:none}.ux-table th{font-family:\"Frutiger-Bold\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;font-weight:400;font-size:13px;color:#fff;text-transform:uppercase;background-color:#899fb2}.ux-table thead tr{background-color:#899fb2}.ux-table tr:nth-child(odd) td{background-color:#eaedf2}.ux-table tr:nth-child(even) td{background-color:#fff}.ux-table__inner{overflow-x:auto;height:auto}.ux-table__inner::before,.ux-table__inner::after{content:\"\";opacity:0;position:absolute;z-index:1;top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%);width:50px;height:calc(100% + 1px);pointer-events:none;-webkit-transition:opacity 0.5s ease;transition:opacity 0.5s ease}.ux-table__inner::before{background:-webkit-gradient(linear, right top, left top, color-stop(0, rgba(255, 255, 255, 0)), to(rgba(0, 0, 0, 0.2)));background:linear-gradient(to left, rgba(255, 255, 255, 0) 0, rgba(0, 0, 0, 0.2) 100%)}.ux-table__inner::after{right:0;background:-webkit-gradient(linear, left top, right top, color-stop(0, rgba(255, 255, 255, 0.1)), to(#fff));background:linear-gradient(to right, rgba(255, 255, 255, 0.1) 0, #fff 100%)}.ux-table__fixed-link{padding:9px 2px 9px 12px;-webkit-transform:translate(-50%, -50%);transform:translate(-50%, -50%);position:absolute;right:0;top:50%;display:none}.ux-table--has-left-shadow .ux-table__inner::before{opacity:1}.ux-table--has-right-shadow .ux-table__inner::after{opacity:1}.ux-table--full-width table{min-width:100%}.ux-table--is-fixed table{min-width:auto}.ux-table--is-fixed .ux-table__fixed-link{display:inline-block}";
applyPolyfills();
var Table = /** @class */ (function () {
    function Table(hostRef) {
        var _this = this;
        registerInstance(this, hostRef);
        /** zero-based index of the column that should be fixed on smaller viewports - defaults to the first col */
        this.fixedColIndex = 0;
        /** maximum number of pixels that the fixed column is allowed to be wide */
        this.maxFixedColWidth = 250;
        /** the table should always be at least 100% wide */
        this.fullWidth = false;
        /** the table should sort its static data by itself. Do not use this if the data needs to be sorted by some logic (i.e. via an API) */
        this.sortable = false;
        /** The link in the last column will be added into the fixed column on smaller viewports */
        this.hasFixedLink = false;
        /** is true when the table is horizontally scrollable (has a fixed col) */
        this.isFixed = false;
        /** width of the fixed col */
        this.fixedColWidth = 250;
        /** the left shadow is visible */
        this.leftShadow = false;
        /** the right shadow is visible */
        this.rightShadow = false;
        this.contentObserver = new MutationObserver(debounce(function () { return _this.onContentChange(); }, 100));
        this.onResize = throttle(function () { return _this.calculateTableState(); }, 200);
        this.onScroll = throttle(function () { return _this.calculateShadows(); }, 10);
    }
    Table.prototype.connectedCallback = function () {
        this.uniqueId = "ux-table-id-" + idCounter++;
        this.table = this.element.querySelector("table");
        window.addEventListener("resize", this.onResize);
    };
    Table.prototype.componentDidLoad = function () {
        this.addFixedLink();
        this.calculateFixedColWidth();
        this.calculateTableState();
        this.calculateShadows();
        this.syncRowHeight();
        this.contentObserver.observe(this.innerDiv, {
            childList: true,
            subtree: true,
        });
    };
    Table.prototype.disconnectedCallback = function () {
        window.removeEventListener("resize", this.onResize);
        this.contentObserver.disconnect();
    };
    Table.prototype.onContentChange = function () {
        this.addFixedLink();
        this.syncRowHeight();
        this.calculateFixedColWidth();
        this.calculateTableState();
        this.calculateShadows();
    };
    Table.prototype.calculateTableState = function () {
        var containerWidth = this.element.getBoundingClientRect().width;
        var tableRect = this.table.getBoundingClientRect();
        var tableWidth = tableRect.width + (this.isFixed ? this.fixedColWidth : 0);
        this.isFixed = containerWidth < tableWidth;
    };
    Table.prototype.calculateFixedColWidth = function () {
        var _a = this, table = _a.table, fixedColIndex = _a.fixedColIndex, maxFixedColWidth = _a.maxFixedColWidth;
        var fixedCells = table.querySelectorAll("td:nth-child(" + (fixedColIndex + 1) + ")\n            ,th:nth-child(" + (fixedColIndex + 1) + ")");
        var fixedCellsArray = [].slice.call(fixedCells);
        var width = 0;
        // we only calculate the width for the first 50 items to prevent that bigger tables get slow.
        fixedCellsArray
            .slice(0, 50)
            .forEach(function (cell) {
            var cellWidth = cell.offsetWidth;
            width = cellWidth > width ? cellWidth : width;
        });
        this.fixedColWidth =
            width > maxFixedColWidth ? maxFixedColWidth : width;
    };
    Table.prototype.calculateShadows = function () {
        var scrollLeft = this.innerDiv.scrollLeft;
        var containerWidth = this.innerDiv.getBoundingClientRect().width;
        var tableWidth = this.table.getBoundingClientRect().width +
            (this.isFixed ? this.fixedColWidth : 0);
        this.leftShadow = this.isFixed && scrollLeft > 0;
        this.rightShadow = scrollLeft + containerWidth < tableWidth;
    };
    /** the height of multi-line cells might differ from the fixed cell, so we need to sync it to prevent gaps */
    Table.prototype.syncRowHeight = function () {
        var _this = this;
        var rows = this.table.querySelectorAll("tr");
        [].forEach.call(rows, function (row) {
            var rowHeight = row.getBoundingClientRect().height;
            var fixedCell = row.querySelector("th:nth-child(" + (_this.fixedColIndex + 1) + "),td:nth-child(" + (_this.fixedColIndex + 1) + ")");
            var fixedCellHeight = fixedCell.getBoundingClientRect().height;
            var height = Math.max(rowHeight, fixedCellHeight);
            row.style.height = height + "px";
            fixedCell.style.height = height + "px";
        });
    };
    Table.prototype.sortRows = function (e) {
        if (!this.sortable)
            return;
        var sorter = e.target;
        var th = sorter.closest("th");
        var titleRow = th.parentElement;
        var colIndex = [].indexOf.call(titleRow.children, th);
        var table = th.closest("table");
        var sortAttr = "data-sort";
        var getCellValue = function (tr, idx) { return tr.children[idx].hasAttribute(sortAttr)
            ? tr.children[idx].getAttribute(sortAttr)
            : tr.children[idx].textContent; };
        var comparer = function (idx, asc) { return function (a, b) { return getCellValue(asc ? a : b, idx).localeCompare(getCellValue(asc ? b : a, idx)); }; };
        [].slice
            .call(table.querySelectorAll("tr"))
            .filter(function (tr) { return !tr.isSameNode(titleRow); })
            .sort(comparer(colIndex, sorter.sortedDirection === "asc"))
            .forEach(function (tr) { return table.appendChild(tr); });
    };
    Table.prototype.addFixedLink = function () {
        if (!this.hasFixedLink)
            return;
        var table = this.table;
        var tableRows = table.querySelectorAll("tr");
        var tableRowsArray = [].slice.call(tableRows);
        var fixedLinkClass = "ux-table__fixed-link";
        tableRowsArray.forEach(function (tableRow) {
            var lastCellIndex = tableRow.children.length - 1;
            var lastRowCell = tableRow.children[lastCellIndex];
            var link = lastRowCell.querySelector("a");
            if (!link)
                return;
            var firstRowCell = tableRow.children[0];
            var hasFixedLink = firstRowCell.querySelector("." + fixedLinkClass);
            if (!hasFixedLink) {
                var clonedLink = link.cloneNode(true);
                clonedLink.className = fixedLinkClass;
                clonedLink.innerHTML = '<ux-icon name="arrow-right"></ux-icon>';
                firstRowCell.insertAdjacentElement("beforeend", clonedLink);
            }
        });
    };
    Table.prototype.render = function () {
        var _a;
        var _this = this;
        var baseClass = "ux-table";
        var fixedClass = baseClass + "--is-fixed";
        var _b = this, uniqueId = _b.uniqueId, isFixed = _b.isFixed, fixedColIndex = _b.fixedColIndex, fixedColWidth = _b.fixedColWidth, maxFixedColWidth = _b.maxFixedColWidth, leftShadow = _b.leftShadow, rightShadow = _b.rightShadow, fullWidth = _b.fullWidth;
        var fixedCol = fixedColIndex + 1; // CSS selectors work with an 1-based index
        return (h(Host, { class: (_a = {},
                _a[baseClass] = true,
                _a[fixedClass] = isFixed,
                _a[baseClass + "--has-left-shadow"] = leftShadow,
                _a[baseClass + "--has-right-shadow"] = rightShadow,
                _a[baseClass + "--full-width"] = fullWidth,
                _a) }, h("style", null, "\n                    #" + uniqueId + " th:nth-child(" + fixedCol + "),\n                    #" + uniqueId + " td:nth-child(" + fixedCol + ") {\n                        max-width: " + maxFixedColWidth + "px;\n                    }\n                    ." + fixedClass + " #" + uniqueId + " th:nth-child(" + fixedCol + "),\n                    ." + fixedClass + " #" + uniqueId + " td:nth-child(" + fixedCol + ") {\n                        position: absolute;\n                        left: 0;\n                        width: " + fixedColWidth + "px;\n                    }\n                    ." + fixedClass + " #" + uniqueId + " table {\n                        margin-left: " + fixedColWidth + "px;\n                    }\n                    #" + uniqueId + ":before {\n                        left: " + fixedColWidth + "px;\n                    }\n                "), h("div", { class: baseClass + "__inner", ref: function (el) { return (_this.innerDiv = el); }, onScroll: function () { return _this.onScroll(); }, id: uniqueId }, h("slot", null))));
    };
    Object.defineProperty(Table.prototype, "element", {
        get: function () { return getElement(this); },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Table, "watchers", {
        get: function () {
            return {
                "isFixed": ["calculateShadows", "syncRowHeight"]
            };
        },
        enumerable: false,
        configurable: true
    });
    return Table;
}());
/** this variable is incremented by each instance */
var idCounter = 0;
Table.style = tableCss;
export { Table as ux_table };
