import { r as registerInstance, c as createEvent, h, H as Host } from './index-6beb7a83.js';
import { a as api } from './api-0a9a464a.js';
var toggleButtonCss = ".ux-toggle-button{cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;display:inline-block;padding:0 5px;color:#131313}.ux-toggle-button--on{color:#bbd03a}.ux-toggle-button--has-error{color:#ff0201}.ux-toggle-button .ux-icon{fill:currentColor}";
var ToggleButton = /** @class */ (function () {
    function ToggleButton(hostRef) {
        registerInstance(this, hostRef);
        /** is the toggle on or off */
        this.on = false;
        /** this id is used to identify similar toggleButtons to synchronise them */
        this.syncId = "";
        /** optional url to be called when the item should be toggled */
        this.toggleUrl = "";
        /** optional url to be called when the item should be untoggled (-> off), can be left empty if it is identical to toggleUrl */
        this.untoggleUrl = "";
        /** text to show on toggle button in "on" state (if used with icon it will be the title attribute) */
        this.textOn = "";
        /** text to show on toggle button in "off" state (if used with icon it will be the title attribute) */
        this.textOff = "";
        /** name of icon to show when in state "on" */
        this.iconOn = "";
        /** name of icon to show when in state "off" */
        this.iconOff = "";
        /** the component sets this to true when an error occurs while communicating with the API */
        this.error = false;
        this.didToggle = createEvent(this, "uxToggle", 7);
        this.toggleFailed = createEvent(this, "uxToggleFailed", 7);
    }
    ToggleButton.prototype.toggle = function () {
        var _this = this;
        var on = this.on;
        this.on = !on;
        this.error = false;
        this.waitForToggle(function () {
            _this.didToggle.emit(_this.on);
            _this.syncOtherButtons();
        }, function () {
            _this.on = on;
            _this.error = true;
            _this.toggleFailed.emit(_this.on);
        });
    };
    ToggleButton.prototype.syncOtherButtons = function () {
        var _a = this, syncId = _a.syncId, on = _a.on;
        if (syncId === "")
            return;
        var sameButtons = document.querySelectorAll("ux-toggle-button[sync-id=" + syncId + "]");
        [].forEach.call(sameButtons, function (button) {
            button.on = on;
        });
    };
    ToggleButton.prototype.waitForToggle = function (callback, error) {
        var _a = this, toggleUrl = _a.toggleUrl, untoggleUrl = _a.untoggleUrl, on = _a.on;
        if (toggleUrl === "") {
            callback();
            return;
        }
        var url = on && untoggleUrl !== "" ? untoggleUrl : toggleUrl;
        api(url).then(callback).catch(error);
    };
    ToggleButton.prototype.render = function () {
        var _a;
        var _this = this;
        var baseClass = "ux-toggle-button";
        var _b = this, on = _b.on, textOff = _b.textOff, textOn = _b.textOn, iconOff = _b.iconOff, iconOn = _b.iconOn, error = _b.error;
        var text = on ? textOn : textOff;
        var hasIcons = iconOn !== "" && iconOff !== "";
        return (h(Host, { class: (_a = {},
                _a[baseClass] = true,
                _a["ux-toggle-button--on"] = on,
                _a["ux-toggle-button--off"] = !on,
                _a["ux-toggle-button--has-error"] = error,
                _a), onClick: function (e) {
                e.preventDefault();
                _this.toggle();
            }, title: hasIcons ? text : "" }, !hasIcons && text, hasIcons && h("ux-icon", { name: on ? iconOn : iconOff })));
    };
    return ToggleButton;
}());
ToggleButton.style = toggleButtonCss;
export { ToggleButton as ux_toggle_button };
