import { r as registerInstance, c as createEvent, h, H as Host, g as getElement } from './index-6beb7a83.js';
import { a as api } from './api-0a9a464a.js';

function getAttributes(element) {
    if (typeof element === "undefined")
        return {};
    const nodeMap = element.attributes;
    const length = nodeMap.length;
    return Object.keys(nodeMap).reduce((props, current) => {
        try {
            const numCurrent = parseInt(current);
            if (numCurrent < length) {
                const property = nodeMap[current];
                return Object.assign(Object.assign({}, props), { [property.name]: property.value });
            }
        }
        catch (err) {
            // nothing
        }
    }, {});
}

const filterObject = (originalObject, ignoreList) => Object.keys(originalObject)
    .filter((key) => !ignoreList.includes(key))
    .reduce((obj, key) => (Object.assign(Object.assign({}, obj), { [key]: originalObject[key] })), {});

const dataIngestCss = ".ux-data-ingest{display:block}";

/** these common HTML attributes will not be considered for fetching data */
const ignoreAttributeList = [
    "class",
    "id",
    "style",
    "slot",
    "tabindex",
    "title",
];
class DataIngest {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        /** contains the filtered attributes with their URLs */
        this.attributes = {};
        this.startRequest = createEvent(this, "uxStartRequest", 7);
    }
    componentWillLoad() {
        this.refreshAttributes();
        this.observer = new MutationObserver(() => this.refreshAttributes());
        this.observer.observe(this.host, {
            attributes: true,
            childList: false,
            subtree: false,
        });
    }
    disconnectedCallback() {
        this.observer.disconnect();
    }
    /** reads the attributes and their URLs and matches them with the previous ones */
    refreshAttributes() {
        const oldAttributes = this.attributes;
        this.attributes = filterObject(getAttributes(this.host), ignoreAttributeList);
        Object.keys(this.attributes).forEach((key) => {
            if (this.attributes[key] !== oldAttributes[key]) {
                this.loadData(key);
            }
        });
    }
    /** loads the data from the url supplied via attribute to put it onto the child element */
    loadData(attributeName) {
        const url = this.attributes[attributeName];
        if (url === "")
            return;
        this.startRequest.emit(attributeName);
        const child = this.host.firstElementChild;
        const loading = `${attributeName}Loading`;
        if (child === null) {
            return;
        }
        child[loading] = true;
        api(url)
            .then((result) => {
            child[loading] = false;
            child[attributeName] = result;
        })
            .catch(() => {
            child[loading] = false;
        });
    }
    render() {
        return (h(Host, { class: "ux-data-ingest" }, h("slot", null)));
    }
    get host() { return getElement(this); }
}
DataIngest.style = dataIngestCss;

export { DataIngest as ux_data_ingest };
