import { r as registerInstance, c as createEvent, h, g as getElement, H as Host } from './index-6beb7a83.js';
import { t as throttle } from './throttle-2fb7d237.js';

class InfiniteScrollSensor {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        /** is true after the event was fired. This prevents the event from firing again. set this to false to re-enable the event */
        this.hasFired = false;
        /** this name will also be in the event */
        this.name = "";
        this.onScroll = throttle(() => {
            if (!this.hasFired && this.sensor !== null && isInView(this.sensor)) {
                this.hasFired = true;
                this.scrolledIntoView.emit(this.name);
            }
        }, 100);
        this.scrolledIntoView = createEvent(this, "uxInfiniteScrollSensorScrolledIntoView", 7);
    }
    connectedCallback() {
        document.addEventListener("scroll", this.onScroll);
    }
    disconnectedCallback() {
        document.removeEventListener("scroll", this.onScroll);
    }
    render() {
        return h(Host, { class: "ux-infinite-scroll-sensor" });
    }
    get sensor() { return getElement(this); }
}
function isInView(el) {
    const box = el.getBoundingClientRect();
    return box.top < window.innerHeight && box.bottom >= 0;
}

export { InfiniteScrollSensor as ux_infinite_scroll_sensor };
