import { r as registerInstance, h, H as Host, g as getElement } from './index-6beb7a83.js';

const getValidatedValue = (newValue, oldValue, max, min) => {
    const newNumber = +newValue;
    if (isNaN(newNumber)) {
        return oldValue;
    }
    if (!isNaN(max) && newNumber > max) {
        return max;
    }
    if (!isNaN(min) && newNumber < min) {
        return min;
    }
    return Math.round(newNumber);
};
const calculateValue = (type, value, increment, max, min) => {
    const factor = type === "decrement" ? -1 : 1;
    const newValue = value + factor * increment;
    return getValidatedValue(newValue, value, max, min);
};
const getNumberValue = (string) => {
    const number = string === "" ? NaN : +string;
    return number;
};

const numberInputCss = ".ux-number-input{display:-ms-flexbox;display:flex;border:1px solid black}.ux-number-input__input[type=number]{text-align:center;padding:12px 10px;-ms-flex:1 1 0px;flex:1 1 0;width:auto;min-width:45px;border-radius:0;border:1px solid black;border-top-width:0;border-bottom-width:0;appearance:none;-webkit-appearance:none;-moz-appearance:textfield}.ux-number-input__input[type=number]::-webkit-outer-spin-button,.ux-number-input__input[type=number]::-webkit-inner-spin-button{-webkit-appearance:none;appearance:none}.ux-number-input__btn{-webkit-appearance:none;-moz-appearance:none;appearance:none;border:0;background:#e7e7e7;min-width:45px;-ms-flex:0 1 45px;flex:0 1 45px;text-align:center;border-radius:0}";

class NumberInput {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        /** name attribute for the input */
        this.name = "";
        /** initial value for the input */
        this.initialValue = "0";
        /** size of increment/decrement for the plus/minus button */
        this.step = "1";
        /** max value */
        this.max = "";
        /** min value */
        this.min = "";
    }
    componentWillLoad() {
        const { initialValue } = this;
        const initialNumber = +initialValue;
        if (!isNaN(initialNumber)) {
            this.value = initialNumber;
        }
        this.setNumbers();
    }
    setNumbers() {
        const { max, min, step } = this;
        this.minValue = getNumberValue(min);
        this.maxValue = getNumberValue(max);
        const stepValue = getNumberValue(step);
        this.stepValue = isNaN(stepValue) ? 1 : stepValue;
    }
    handlePlus() {
        this.changeValue("increment");
    }
    handleMinus() {
        this.changeValue("decrement");
    }
    changeValue(type = "increment") {
        const { stepValue, maxValue, minValue, value } = this;
        this.value = calculateValue(type, value, stepValue, maxValue, minValue);
    }
    onChange(event) {
        const { maxValue, minValue } = this;
        const { value } = event.target;
        this.value = getValidatedValue(value, this.value, maxValue, minValue);
        event.target.value = this.value;
    }
    render() {
        const baseClass = "ux-number-input";
        const { name, max, min, stepValue, value } = this;
        return (h(Host, { class: baseClass }, h("button", { type: "button", class: `${baseClass}__btn`, onClick: () => this.handleMinus() }, "\u2013"), h("input", { class: `${baseClass}__input`, name: name, step: stepValue.toString(), type: "number", max: max, min: min, value: value, onInput: (event) => this.onChange(event) }), h("button", { type: "button", class: `${baseClass}__btn`, onClick: () => this.handlePlus() }, "+")));
    }
    get domNode() { return getElement(this); }
    static get watchers() { return {
        "min": ["setNumbers"],
        "max": ["setNumbers"],
        "step": ["setNumbers"]
    }; }
}
NumberInput.style = numberInputCss;

export { NumberInput as ux_number_input };
