import { r as registerInstance, c as createEvent, h, H as Host, g as getElement } from './index-6beb7a83.js';
import { a as applyPolyfills } from './element-f64f78c4.js';

const tableSortCss = ".ux-table-sort{cursor:pointer}.ux-table-sort[sorted-direction=asc]{border-bottom:solid 1px}.ux-table-sort[sorted-direction=asc] .ux-icon__sort-down{fill:#bbd03a}.ux-table-sort[sorted-direction=desc]{border-bottom:solid 1px}.ux-table-sort[sorted-direction=desc] .ux-icon__sort-up{fill:#bbd03a}.ux-table-sort__icon{font-size:12px;fill:currentColor}";

applyPolyfills();
class TableSort {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        /** indicates in which direction the data is already sorted. This has to be empty when it is not sorted yet. Setting this does not trigger the sorting event. Clicking the button will update this attribute. */
        this.sortedDirection = "";
        this.sortEvent = createEvent(this, "uxTableSort", 7);
    }
    sort() {
        this.sortedDirection = this.sortedDirection !== "asc" ? "asc" : "desc";
        const name = this.sortedDirection === "asc" ? this.ascName : this.descName;
        this.sortEvent.emit(name);
        const allSorters = this.domElement
            .closest("tr")
            .querySelectorAll("ux-table-sort");
        [].forEach.call(allSorters, (element) => {
            if (element.isEqualNode(this.domElement))
                return;
            element.sortedDirection = "";
        });
    }
    render() {
        const baseClass = "ux-table-sort";
        return (h(Host, { class: baseClass, onClick: () => this.sort() }, h("slot", null), "\u00A0", h("ux-icon", { class: `${baseClass}__icon`, name: "sort" })));
    }
    get domElement() { return getElement(this); }
}
TableSort.style = tableSortCss;

export { TableSort as ux_table_sort };
