import { r as registerInstance, c as createEvent, h, H as Host } from './index-6beb7a83.js';
import { a as api } from './api-0a9a464a.js';

const toggleButtonCss = ".ux-toggle-button{cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;display:inline-block;padding:0 5px;color:#131313}.ux-toggle-button--on{color:#bbd03a}.ux-toggle-button--has-error{color:#ff0201}.ux-toggle-button .ux-icon{fill:currentColor}";

class ToggleButton {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        /** is the toggle on or off */
        this.on = false;
        /** this id is used to identify similar toggleButtons to synchronise them */
        this.syncId = "";
        /** optional url to be called when the item should be toggled */
        this.toggleUrl = "";
        /** optional url to be called when the item should be untoggled (-> off), can be left empty if it is identical to toggleUrl */
        this.untoggleUrl = "";
        /** text to show on toggle button in "on" state (if used with icon it will be the title attribute) */
        this.textOn = "";
        /** text to show on toggle button in "off" state (if used with icon it will be the title attribute) */
        this.textOff = "";
        /** name of icon to show when in state "on" */
        this.iconOn = "";
        /** name of icon to show when in state "off" */
        this.iconOff = "";
        /** the component sets this to true when an error occurs while communicating with the API */
        this.error = false;
        this.didToggle = createEvent(this, "uxToggle", 7);
        this.toggleFailed = createEvent(this, "uxToggleFailed", 7);
    }
    toggle() {
        const { on } = this;
        this.on = !on;
        this.error = false;
        this.waitForToggle(() => {
            this.didToggle.emit(this.on);
            this.syncOtherButtons();
        }, () => {
            this.on = on;
            this.error = true;
            this.toggleFailed.emit(this.on);
        });
    }
    syncOtherButtons() {
        const { syncId, on } = this;
        if (syncId === "")
            return;
        const sameButtons = document.querySelectorAll(`ux-toggle-button[sync-id=${syncId}]`);
        [].forEach.call(sameButtons, (button) => {
            button.on = on;
        });
    }
    waitForToggle(callback, error) {
        const { toggleUrl, untoggleUrl, on } = this;
        if (toggleUrl === "") {
            callback();
            return;
        }
        const url = on && untoggleUrl !== "" ? untoggleUrl : toggleUrl;
        api(url).then(callback).catch(error);
    }
    render() {
        const baseClass = "ux-toggle-button";
        const { on, textOff, textOn, iconOff, iconOn, error } = this;
        const text = on ? textOn : textOff;
        const hasIcons = iconOn !== "" && iconOff !== "";
        return (h(Host, { class: {
                [baseClass]: true,
                "ux-toggle-button--on": on,
                "ux-toggle-button--off": !on,
                "ux-toggle-button--has-error": error,
            }, onClick: (e) => {
                e.preventDefault();
                this.toggle();
            }, title: hasIcons ? text : "" }, !hasIcons && text, hasIcons && h("ux-icon", { name: on ? iconOn : iconOff })));
    }
}
ToggleButton.style = toggleButtonCss;

export { ToggleButton as ux_toggle_button };
